var async = require('async')
var getDB = require('./getDB')
var inspect = require('eyespect').inspector()
var should = require('should')
var findUpload = require('../findUpload')
var assert = require('assert')
var path = require('path')
var fs = require('fs')
var configFilePath = path.join(__dirname, 'config.json')
assert.ok(fs.existsSync(configFilePath), 'config file not found at path: ' + configFilePath)
var config = require('nconf').argv().env().file({file: configFilePath})

describe('findUpload test', function () {
  this.slow('1s')
  var db
  before(function (done) {
    getDB(config, function (err, reply) {
      should.not.exist(err)
      should.exist(reply)
      db = reply
      removeIfNeeded({db: db}, function (err) {
        should.not.exist(err)
        done()
      })
    })
  })

  it('should give error when upload is not found', function (done) {
    var data = {
      uploadID: 'fooUploadID',
      db: db
    }
    findUpload(data, function (err, reply) {
      should.exist(err)
      done()
    })
  })

  it('should return upload when one is found', function (done) {
    var upload = {
      foo: 'bar'
    }
    db.save(upload, function (err, reply) {
      should.not.exist(err)
      var uploadID = reply._id
      var data = {
        uploadID: uploadID,
        db: db
      }
      findUpload(data, function (err, reply) {
        should.not.exist(err)
        should.exist(reply)
        uploadID.should.eql(reply._id)
        reply.should.have.property('_rev')
        done()
      })
    })
  })
})


function removeIfNeeded(data, callback) {
  var db = data.db
  db.view('upload/all', {}, function (err, docs) {
    if (err) { return callback(err) }
    if (docs.length === 0) {
      return callback()
    }
    async.forEachSeries(
      docs,
      function (doc, cb) {
        var rev = doc.value._rev
        var id = doc.value._id
        db.remove(id, rev, cb)
      }, callback)
  })
}
