var async = require('async')
var getDB = require('./getDB')
var inspect = require('eyespect').inspector()
var should = require('should')
var update = require('../update')
var assert = require('assert')
var path = require('path')
var fs = require('fs')
var configFilePath = path.join(__dirname, 'config.json')
assert.ok(fs.existsSync(configFilePath), 'config file not found at path: ' + configFilePath)
var config = require('nconf').argv().env().file({file: configFilePath})

describe('update upload test', function () {
  var data
  var db
  before(function (done) {
    getDB(config, function (err, reply) {
      should.not.exist(err)
      should.exist(reply)
      db = reply
      removeIfNeeded({db: db}, function (err) {
        should.not.exist(err)
        done()
      })
    })
  })

  beforeEach(function () {
    data = {
      url: 'http://www.google.com',
      upload: {},
      db: db
    }
  })

  it('should reject update requests missing the "url" field', function (done) {
    delete data.url
    update(data, function (err, reply) {
      should.exist(err)
      err.length.should.eql(1)
      var error = err[0]
      error.key.should.eql('url')
      done()
    })
  })

  it('should reject update requests missing the "upload" field', function (done) {
    delete data.upload
    update(data, function (err, reply) {
      should.exist(err)
      err.length.should.eql(1)
      var error = err[0]
      error.key.should.eql('upload')
      done()
    })
  })

  it('should handle valid update requests', function (done) {
    var upload = {
      foo: 'bar',
      ocrStatus: {}
    }
    db.save(upload, function (err, reply) {
      should.not.exist(err)
      upload._id = reply._id
      upload._rev = reply._rev
      var response = {
        statusCode: 200
      }
      var status = 'extraction complete'
      var body = {
        status: status,
        parsed: true,
        textPages: ['foo page 1', 'bar page 2']
      }
      var request = function (opts, cb) {
        cb(null, response, body)
      }
      var updateData = {
        db: db,
        upload: upload,
        url: data.url,
        request: request
      }

      update(updateData, function (err, reply) {
        should.not.exist(err)
        should.exist(reply)
        reply.status.should.eql('ocr complete, waiting to parse')
        done()
      })
    })
  })
})

function removeIfNeeded(data, callback) {
  var db = data.db
  db.view('upload/all', {}, function (err, docs) {
    if (err) { return callback(err) }
    if (docs.length === 0) {
      return callback()
    }
    async.forEachSeries(
      docs,
      function (doc, cb) {
        var rev = doc.value._rev
        var id = doc.value._id
        db.remove(id, rev, cb)
      }, callback)
  })
}
